@@ -304,6 +304,28 @@ class Converter(object):
         overlay_converter(converter, result_converter)
         return result_converter
 
+    def context(self) -> 'ConversionContext':
+        """
+        Create a Conversion context to use in a `with` statement.
+
+        >>> with conversion_rules.context() as cv:
+        ...     # Do something while using those conversion_rules.
+        >>> # Do something else whith the earlier conversion rules restored.
+
+        The conversion context is a *copy* of the converter object.
+
+        :return: A :class:`ConversionContext`
+        """
+        return ConversionContext(self)
+
+    def __enter__(self):
+        raise Exception(
+            "Use the converter's method context instead."
+        )
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        return False
+
     def __str__(self):
         res = [str(type(self))]
         for subcv in ('py2rpy', 'rpy2py'):
@@ -351,8 +373,31 @@ class ConversionContext(object):
 
 localconverter = ConversionContext
 
+
+def _raise_missingconverter(obj):
+    _missingconverter_msg = """
+    Conversion rules for `rpy2.robjects` appear to be missing. Those
+    rules are in a Python `contextvars.ContextVar`. This could be caused
+    by multithreading code not passing context to the thread.
+    Check rpy2's documentation about conversions.
+    """
+    raise NotImplementedError(_missingconverter_msg)
+
+
+missingconverter = Converter('missing')
+
+missingconverter.rpy2py.register(
+    object,
+    _raise_missingconverter
+)
+
+missingconverter.py2rpy.register(
+    object,
+    _raise_missingconverter
+)
+
 converter_ctx = contextvars.ContextVar('converter',
-                                       default=Converter('empty'))
+                                       default=missingconverter)
 
 
 def _deprecated_converter():
@@ -362,13 +407,13 @@ def _deprecated_converter():
 def _deprecated_py2rpy(
         obj: Any
 ) -> _rinterface_capi.SupportsSEXP:
-    return converter_ctx.get('converter').py2rpy(obj)
+    return converter_ctx.get('converter').py2rpy(obj)  # type: ignore
 
 
 def _deprecated_rpy2py(
         obj: Any
 ) -> _rinterface_capi.SupportsSEXP:
-    return converter_ctx.get('converter').rpy2py(obj)
+    return converter_ctx.get('converter').rpy2py(obj)  # type: ignore
 
 
 def get_conversion():
